package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`MP`!````,"5```````!``````````)"C````
M`````````$``.``(`$``&P`:``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````;`````````!L``````````0`````````!````
M!0````````````````!``````````$```````#28````````-)@`````````
M``$```````$````&````P)T```````#`G4$``````,"=00``````B`0`````
M``#P%````````````0```````@````8```#8G0```````-B=00``````V)U!
M`````````@`````````"````````"``````````$````!````!P"````````
M'`)````````<`D```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```#`G0```````,"=00``````P)U!``````!``@``````
M`$`"`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`ET\RF=GO9+,!=);RY8>GZ?D#EV)A````!0```!`````*````H!``*`)&
M$0```&``5@)0&(((!"!(`!$1``@0`@`@`````````$@"(`X`"P``A`*H00@%
M(&@(Q$DX0A25!D$H"BA8B($%8`26"`E"2G!``!@!`4!""`!`@(S`!``($)`0
M`P$`"($8@(%`0(*9@"Q`"`(!!"``8``)!)$CA(J75&`%``````````8````'
M````"0`````````````````````````*````#`````X````0````$0```!(`
M```4````%P`````````9```````````````:````'0```!X`````````(@``
M`",````D`````````"4````F````*@`````````L```````````````M````
M+@```"\````P`````````#0````U`````````#D``````````````#H````]
M````/@`````````_````0````$(```!$````1P````````!*````2P```$P`
M``!-`````````$X```````````````````````````````````!/````4```
M``````!2`````````%0```!6````6`````````````````````````!9````
M70````````!?`````````&$`````````8P```&0``````````````&8```!G
M````:0```&H```!M````7Y:3'*-:[Y#"CH?_5]N3'`TZEPO2402$@72"#7KP
M2FM]08[%=E0\E,T_#*_W(\X@B0=PTR!TL`+59-1\9J_,9BY./?;;]P!>!J2'
M_P&O-.BQ2)WGSMY'+>"G`@K/2J[_XT?&`3Y^EGS&#N`][#^0`FUSA<7%B060
M89CO$@$C^:2=NY,<0D75['SM$0]0[A'CA_F<@5J:.P^[E9,<04V=?*?=HVM9
M[Y=Y.?*+'`P4XIX$,J6%H@+V&=O-XY[[H6Q@ZM/O#L@Y0!\R8MOMN8WQ#NG[
MP\+LWI,<2B)]_PN*$%>M2^/`V7%8'"O0X2(:G]:]+0ZQ<U@[0!_#Y3\LF"+4
M:+KCDGPA_^0.BIC=PFYZ:?J+V357DZT$8C?C\,%#\N_(WX4@3U>DFY;%N9Q`
M4!M]7S&X@@V^VE<;LP&+;W9OXW"]T$M]GB+'J&L)0]8A8F0'?JF<FV+0^H+L
M+/:+:W^:?-"?+/R'\)9\[@M1^?/;TQV0=8(-0V9+$`5LLLT\K3D-%^I:\:/@
M^TGB5\085Y):4OW2[P]NQ=\??)`0Z2W?_D@NQ9NVWJO*G\G5LG$`````````
M```````````````````````1````(``````````````````````````M````
M(``````````````````````````\````(`````````````````````````!0
M````(`````````````````````````"$`P``$@```#`A0```````````````
M``!'`@``$@```#`@0`````````````````#"`@``$@```)`?0```````````
M``````#>`@``$@```(`B0`````````````````!Y!```(``7`"BB00``````
M``````````#-`0``$@```.`A0`````````````````"[`@``$@```$`B0```
M``````````````"]`0``$@```#`?0``````````````````%!0``$@`-`#A6
M0```````0`````````#B`P``$``8`$BB00````````````````!U`@``$@``
M`.`?0`````````````````"@`@``$@```+`B0`````````````````"Y!```
M$0`7`$"B00``````"``````````A`P``$@```.`>0``````````````````A
M!0``$@`-`,110```````^`,```````!>!```$@`-`/Q"0```````-`$`````
M``"+`P``$@```/`?0`````````````````"&`@``$@```(`@0```````````
M```````R`P``$@`````?0`````````````````#Q`P``$``8`+"R00``````
M```````````/`0``$@```"`A0`````````````````!J!```$@`-``1(0```
M````P`D```````"3!```$@`-`/0_0```````\``````````\!```$@```$`A
M0`````````````````!1!```$@`-`-Q"0```````(`````````!P`@``$@``
M`-`>0`````````````````"M`@``$@```'`@0`````````````````"6`0``
M$@```'`A0``````````````````.`P``$@```(`A0`````````````````">
M`P``(0`8`&BB00``````"``````````O`@``$@```%`B0```````````````
M```V`@``$@```*`B0`````````````````#0`@``$@```+`>0```````````
M``````#/`P``$``7`$BB00````````````````"U`@``$@```-`@0```````
M``````````#K`@``$@```!`A0`````````````````">````$@```"`B0```
M```````````````I`@``$@```*`@0`````````````````!6`P``$@`````B
M0`````````````````!/`@``$@```#`B0`````````````````"?`P``(0`8
M`&BB00``````"`````````#\`P``$``8`+"R00`````````````````K`P``
M$0`8`$BB00``````"``````````)!```$@`-``Q70```````!`````````"A
M`0``$@```,`?0`````````````````!O`0``$@```+`@0```````````````
M``"I!```$@`-`)160```````>`````````#E!```$@`-`,!&0```````1`$`
M```````3!```$@`.`!!70`````````````````"/`@``$@```)`@0```````
M``````````!]!```$@`-`#`E0`````````````````#2!```$@`+`$@>0```
M``````````````"^````$@```&`A0`````````````````#)`@``$@```*`>
M0````````````````````P``$@```+`?0``````````````````"`0``$0`8
M`%BB00```````0````````"$!```$0`/`"!70```````!`````````#6`P``
M$``8`$BB00````````````````!=`P``$@```,`A0`````````````````!U
M`P``$@```)`>0`````````````````!J````$@```+`A0```````````````
M```<`0``$@```/`A0`````````````````#0!```$@`-`'`_0```````-```
M```````X`0``$@```'`?0``````````````````$!```$``8`+"R00``````
M``````````#8!```$@`-`.A`0```````]`$```````#3````$@```"`?0```
M``````````````!>`@``$@```$`?0`````````````````"'````$@```)`B
M0``````````````````5`@``$@```&`@0`````````````````"O`0``$@``
M`!`B0`````````````````#A````$@```!`@0`````````````````#S````
M$@```&`B0``````````````````M`0``$0`8`%"B00``````!`````````"=
M`P``$0`8`&BB00``````"`````````!A`0``$@```-`?0```````````````
M``#7`@``$@`````@0`````````````````#P`P``$``8`+"R00``````````
M``````#W!```$@`-``1&0```````E``````````9`P``$@```!`?0```````
M``````````"O````$@```&`?0`````````````````!G`P``$@```,`>0```
M``````````````!W!```$``7`"BB00````````````````"]`P``$0`8`&"B
M00``````"``````````J!```$@`-`)A&0```````*`````````#K`0``$@``
M`"`@0`````````````````#8`0``$@```%`@0`````````````````"8`P``
M$@`-`-`B0```````5`(```````!"`P``$@`````A0``````````````````]
M`0``$@```*`A0``````````````````Y`P``$@```/`>0```````````````
M``#V`0``$0`8`'"B00``````$P````````#Y`@``$@```(`>0```````````
M``````#E`@``$@```%`A0`````````````````!]`@``$@```%`?0```````
M``````````#D`0``$@```*`?0`````````````````!]`P``$@```.`@0```
M``````````````##!```$@`-`#!$0```````U`$```````!)`P``$@```(`?
M0`````````````````!"`0``$@```-`A0`````````````````"G`@``$@``
M`,`B0`````````````````!%!```$@`-`+Q50```````?`````````!X````
M$@```/`@0`````````````````!_`0``$@```'`B0``````````````````9
M!```$@`-`.1`0```````!`````````"(`0``$@```$`@0```````````````
M``!.`0``$@```)`A0```````````````````;&EB<&5R;"YS;RXU+C(P`%])
M5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?2G9?
M4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7W-A=F5?9&5S=')U8W1O
M<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A
M:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!0
M97)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=35G!V`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L7V1E
M<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R
M<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R
M87``;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`
M;W!E;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N
M-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO
M<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A
M8F]R=`!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T
M<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?
M;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D
M;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S
M<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T
M7VUA:6X`7U]E;G9I<F]N`&QD+6QI;G5X+6%A<F-H-C0N<V\N,0!?7W-T86-K
M7V-H:U]G=6%R9`!?961A=&$`7U]B<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?
M7V)S<U]E;F1?7P!?7V5N9%]?`%]E;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C
M=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L
M96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?
M7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`<&%R7VEN:71?96YV`'AS
M7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?
M8VQE86X`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`%A37TEN=&5R;F%L
M<U]005)?0D]/5`!'3$E"0U\R+C$W```````````````"``,``@`"``$````"
M`````0`!``(``@`!``(``0`!``(``@`"``$````!``$``@`!``(``@````(`
M`@`#``,``@`!``(``@````,``@`#``(``0`"``$```````$``0`!``(``0`!
M`````@`"`````0`!``(``@```````0````$``0````(````#````````````
M`@````(``0`!``(````"``$`!``!```````!``(``@`"`````@`"``(``@`"
M``$``@````(``0```````0```````````````0`!`*<#```0````(````)>1
ME@8```0`-P4````````!``$`!0(``!`````@````EY&6!@```P`W!0``````
M``$``0!4`@``$`````````"7D98&```"`#<%````````X)]!```````!!```
M`@``````````````2*)!````````!```+P``````````````4*)!````````
M!```3@``````````````6*)!````````!```/```````````````8*)!````
M````!```6```````````````:*)!````````!```3P``````````````<*)!
M````````!```8````````````````*!!```````"!```80``````````````
M"*!!```````"!```0```````````````$*!!```````"!```.@``````````
M````&*!!```````"!```)0``````````````(*!!```````"!```5@``````
M````````**!!```````"!```'@``````````````,*!!```````"!```$@``
M````````````.*!!```````"!```7P``````````````0*!!```````"!```
M%P``````````````2*!!```````"!```5```````````````4*!!```````"
M!```1P``````````````6*!!```````"!```#```````````````8*!!````
M```"!```2```````````````:*!!```````"!```8P``````````````<*!!
M```````"!```50``````````````>*!!```````"!```1```````````````
M@*!!```````"!```9P``````````````B*!!```````"!```!P``````````
M````D*!!```````"!```9```````````````F*!!```````"!```.P``````
M````````H*!!```````"!```,0``````````````J*!!```````"!```4```
M````````````L*!!```````"!```#P``````````````N*!!```````"!```
M%0``````````````P*!!```````"!```40``````````````R*!!```````"
M!```3```````````````T*!!```````"!```6@``````````````V*!!````
M```"!```!@``````````````X*!!```````"!```;@``````````````Z*!!
M```````"!```6P``````````````\*!!```````"!```2@``````````````
M^*!!```````"!```'P```````````````*%!```````"!```%@``````````
M````"*%!```````"!```-@``````````````$*%!```````"!```*@``````
M````````&*%!```````"!```,@``````````````(*%!```````"!````@``
M````````````**%!```````"!```)P``````````````,*%!```````"!```
M90``````````````.*%!```````"!```:P``````````````0*%!```````"
M!```70``````````````2*%!```````"!```*```````````````4*%!````
M```"!```&0``````````````6*%!```````"!```!0``````````````8*%!
M```````"!```'```````````````:*%!```````"!```8@``````````````
M<*%!```````"!```.0``````````````>*%!```````"!```(```````````
M````@*%!```````"!```(0``````````````B*%!```````"!```;P``````
M````````D*%!```````"!```7@``````````````F*%!```````"!```00``
M````````````H*%!```````"!```/P``````````````J*%!```````"!```
M:```````````````L*%!```````"!```"@``````````````N*%!```````"
M!```0@``````````````P*%!```````"!```*P``````````````R*%!````
M```"!```2P``````````````T*%!```````"!```*0``````````````V*%!
M```````"!```+```````````````X*%!```````"!```"P``````````````
MZ*%!```````"!```(P``````````````\*%!```````"!```30``````````
M````^*%!```````"!```;````````````````*)!```````"!```"```````
M````````"*)!```````"!```20``````````````$*)!```````"!```)```
M````````````&*)!```````"!```$```````````````(*)!```````"!```
M:0``````````````_7N_J?T#`)'*`0"4_7O!J,`#7]8`````\'N_J=```)`1
M_D?Y$.(_D2`"']8?(`/5'R`#U1\@`]70``"P$0)`^1`"`)$@`A_6T```L!$&
M0/D0(@"1(`(?UM```+`1"D#Y$$(`D2`"'];0``"P$0Y`^1!B`)$@`A_6T```
ML!$20/D0@@"1(`(?UM```+`1%D#Y$*(`D2`"'];0``"P$1I`^1#"`)$@`A_6
MT```L!$>0/D0X@"1(`(?UM```+`1(D#Y$`(!D2`"'];0``"P$29`^1`B`9$@
M`A_6T```L!$J0/D00@&1(`(?UM```+`1+D#Y$&(!D2`"'];0``"P$3)`^1""
M`9$@`A_6T```L!$V0/D0H@&1(`(?UM```+`1.D#Y$,(!D2`"'];0``"P$3Y`
M^1#B`9$@`A_6T```L!%"0/D0`@*1(`(?UM```+`11D#Y$"("D2`"'];0``"P
M$4I`^1!"`I$@`A_6T```L!%.0/D08@*1(`(?UM```+`14D#Y$(("D2`"'];0
M``"P$59`^1"B`I$@`A_6T```L!%:0/D0P@*1(`(?UM```+`17D#Y$.("D2`"
M'];0``"0$6)`^1`"`Y$@`A_6T```D!%F0/D0(@.1(`(?UM```)`1:D#Y$$(#
MD2`"'];0``"0$6Y`^1!B`Y$@`A_6T```D!%R0/D0@@.1(`(?UM```)`1=D#Y
M$*(#D2`"'];0``"0$7I`^1#"`Y$@`A_6T```D!%^0/D0X@.1(`(?UM```)`1
M@D#Y$`($D2`"'];0``"0$89`^1`B!)$@`A_6T```D!&*0/D00@21(`(?UM``
M`)`1CD#Y$&($D2`"'];0``"0$9)`^1""!)$@`A_6T```D!&60/D0H@21(`(?
MUM```)`1FD#Y$,($D2`"'];0``"0$9Y`^1#B!)$@`A_6T```D!&B0/D0`@61
M(`(?UM```)`1ID#Y$"(%D2`"'];0``"0$:I`^1!"!9$@`A_6T```D!&N0/D0
M8@61(`(?UM```)`1LD#Y$((%D2`"'];0``"0$;9`^1"B!9$@`A_6T```D!&Z
M0/D0P@61(`(?UM```)`1OD#Y$.(%D2`"'];0``"0$<)`^1`"!I$@`A_6T```
MD!'&0/D0(@:1(`(?UM```)`1RD#Y$$(&D2`"'];0``"0$<Y`^1!B!I$@`A_6
MT```D!'20/D0@@:1(`(?UM```)`1UD#Y$*(&D2`"'];0``"0$=I`^1#"!I$@
M`A_6T```D!'>0/D0X@:1(`(?UM```)`1XD#Y$`('D2`"'];0``"0$>9`^1`B
M!Y$@`A_6T```D!'J0/D00@>1(`(?UM```)`1[D#Y$&('D2`"'];0``"0$?)`
M^1""!Y$@`A_6T```D!'V0/D0H@>1(`(?UM```)`1^D#Y$,('D2`"'];0``"0
M$?Y`^1#B!Y$@`A_6T```D!$"0?D0`@B1(`(?UM```)`1!D'Y$"((D2`"'];0
M``"0$0I!^1!"")$@`A_6T```D!$.0?D08@B1(`(?UM```)`1$D'Y$(((D2`"
M'];]>[JI_0,`D?-3`:GU6P*IU```D*!/`+F#@@F1H2,`^:(?`/FA`P&1HN,`
MD:`S`9%D`$#YI"\`^00`@-+3``"0>/__EP(``)````"00D`&D0"`")'A`P*J
MU`P`E,```)``8$DY0`$`-3K__Y?"``"P0%0!^:`.`+33``"0!?__EV!20KE#
M__^7'U0B.6!20KE`__^7X@,`JF!20KE!R%(Y(0`?,D'($CDZ__^7`LA2.>(#
M9YZA3T"Y`0T`7$(``#(A%``1`L@2.2%\0),@`&.>`"AB'A`@81ZL"0!4(/!]
MT],``+`G__^7Y0,`JJ$C0/G&``"09"(.D:)/0+D#``#P````\"<`0/EC("Z1
MQB!!^0!`+I&C!`#Y7P0`<8,`@%*%`!'XIP``^:8(`/F@#`#Y@X`0N&T'`%0A
M(`"11A``$:``@%+G`("2X\P@BR2$0/@`!``1'P`&:Z1H(_AA__]4X`"`DG8B
M#I$&S":+`0``L`0`@-+C`P6JP`)2^$(,`!$AD#Z1OV@F^&+__Y?U`P`JX`(`
M-'8B#I'``E+XU?[_EP```/"A4P&1`(`CD=X$`)1@`@"T<R(.D92""9%@`E+X
MN/[_ET?__Y>B+T#Y@0)`^4$``<K@`Q4JP0,`M?-30:GU6T*I_7O&J,`#7];`
M`E+X;/__E_4#`"KG__\7P()1^$`!`+0Z#`"4Z___%\$``)````#P(<`)D0``
M+I$=__^71@`#"\___Q<```#PH5,!D0"@(9&\!`"4P((1^,#[_[0K#`"4W/__
M%R``@%)M_O^7W/[_EQ\@`]4```````#`0QT`@-(>`(#2Y0,`JN$#0/GB(P"1
MY@,`D<```%CC``!8!`$`6*?^_Y?>_O^7`````-`B0```````E%9````````,
M5T```````*```/``\$?Y0```M,_^_Q?``U_6`````,$``)#```"0(2`)D0`@
M"9$A'`"1(0``RS\X`/&)``!4@0``6$$``+0@`!_6P`-?U@``````````P0``
MD,```)`A(`F1`"`)D2$``,LA_$.3(?Q!BR'\09.!``"TH@``6$(``+1``!_6
MP`-?UA\@`]4``````````/U[OJG]`P"1\PL`^=,``)!@#DHY@```-=S__Y<@
M`(!28`X*.?,+0/G]>\*HP`-?UOU[OZF@``#P_0,`D0!`-Y$!`$#Y80``M?U[
MP:C=__\7@0``6*'__[0@`#_6^___%P``````````_T,*T<H``)!!@0F1"^``
MD0S@`9']>[^I_0,`D:5C`)$B`$#YHD\!^0(`@-)AA4#XI4``D23\8-,C_$C3
M(GQ8TR?<>-,I_&C3AMQXTV,<>)(H'&C30@`#JN<<<)*$'&C3*1UXDL,<<)+G
M``BJ(>%!JF0`!*KB``*J@0`!JG\!#.NB`!_XH8`?^"']_U2A8P"1HP,"D2:@
M"9%B@%KX8R``D64`7?AD@%_X80!9^'\`!NND``3*(0`"RH$``<HB^'_307Q!
MJB%\0))A"`#Y8?[_5`8$0/E*@0F1!PA`^0@,0/D%`$#YX0`&B@(!)HH)$$#Y
M0@`!JJ'H>],A;$6JHP]`^:P30/GM`"6*(P$#BT)`(8MB``*+(3./TL.$8M-!
M4*OR8PA&JD(``8MC?$"22WQ`D@X!#(ML``6*9.E[TXP!#:J$;$NJC`$!B\P!
M#(MO`"N*C$$DBZ2$8M.$"$6JD'U`DH1\0)*N%T#Y0@`$B@WJ>]/B`0*J[@`.
MBZUM4*I"``&+P@$"BZ\;0/E"0"V+;85BTZL)2ZJ-`#"*:WU`DE%\0)*,`0N*
M+NI[TZT!#*KO`0&+K0$#BP.&8M/.;5&J8PA0JF-\0)+L`0V+C$$NBT(``XIN
M`3&*D'U`DLX!`JJM'T#YS@$$BR2&8M,/ZGO3A`A1JH1\0)+O;5"JK0$!BW$`
M,(JM`0Z+HB-`^8X!!(JM02^++@(.JJ]]0))"``&+RP$+BTL`"XOLZ7O3`H9B
MTXQM3ZI""%"JD0`OBD)\0))L02R+K0$"BI!]0)*K)T#Y+0(-JJT!`XL.ZGO3
MXX5BT\YM4*IK`0&+8PA/JF-\0))K`0V+:T$NBU$`,(J-`0.*;WU`DJPK0/DM
M`@VJK0$$B^[I>],$AF+3SFU/JHP!`8N$"%"JA'Q`DHP!#8N,02Z+<0`OBFT!
M!(J0?4"2JR]`^2T"#:JM`0*+#NI[T^*%8M/.;5"J:P$!BT((3ZI"?$"2:P$-
MBVM!+HN1`#"*C0$"BF]]0)*L,T#Y+0(-JJT!`XONZ7O3`X9BT\YM3ZJ,`0&+
M8PA0JF-\0)*,`0V+C$$NBU$`+XIM`0.*D'U`DJLW0/DM`@VJK0$$BP[J>]/D
MA6+3SFU0JFL!`8N$"$^JA'Q`DFL!#8MK02Z+<0`PBHT!!(IO?4"2K#M`^2T"
M#:JM`0*+[NE[TP*&8M/.;4^JC`$!BT((4*I"?$"2C`$-BXQ!+HN1`"^*;0$"
MBI!]0)*K/T#Y+0(-JJT!`XL.ZGO3XX5BT\YM4*IK`0&+8PA/JF-\0))K`0V+
M:T$NBU$`,(J-`0.*;WU`DJQ#0/DM`@VJK0$$B^[I>],$AF+3SFU/JHP!`8N$
M"%"JA'Q`DHP!#8N,02Z+<0`OBFT!!(J0?4"2JT=`^2T"#:JM`0*+#NI[T^*%
M8M/.;5"J:P$!BT((3ZI"?$"2:P$-BVM!+HN1`#"*C@$"BJQ+0/DN`@ZJ;7U`
MDLX!`XL#AF+38PA0JHP!`8MC?$"240`MBHP!#HMN`0.*JT]`^2X"#JJOZ7O3
MQ`$$B^]M3:IK`0&+:P$$BZ2%8M.,02^+A`A-JI!]0)*-?$"2<0`PB@_J>].,
M`0V*[VU0JBP"#*JD4T#YC`$"BP*&8M-K02^+0@A0JFY]0))"?$"2L0$NBL_I
M>]-K`0**L%=`^>]M3JHK`@NJA``!BQ`"`8N$``R+8P$#BX1`+XL+`@.+PX5B
MTXQ\0))C"$ZJL%M`^7%\0)*/Z7O3[VU,JH0`$8H!`@&+4``LB@0"!*IK02^+
MA``-BV]]0)(A``2+A(5BTXP(3*KNZ7O3@P$#RLYM3ZID``M*XX5BTRY`+HN"
M``*+(72=TJ1?0/DAVZWRT'U`DH0``8MM"$^J@@`"BP3J>].$;%"JHP$,RK)C
M0/EN``Y*1$`DB\,!$8N+?$"24@(!BV_I>]-#`@.+[VU+J@*&8M-0"%"JL6=`
M^6-`+XL"`@W*;WQ`DD(`!$KNZ7O3,0(!BT1`+(O.;4^J)`($B[%K0/F.0"Z+
M9(5BTXL(2ZK>?4"28@$0RLSK>]-#``-*,0(!BXQM7JIC0"V+(P(#B[%O0/ER
M0"R+XX5BTV\(3ZI-?D"2X@$+RJSI>]-"``Y*,0(!BXQM3:I"0#"+(@("B[%S
M0/E,0"R+PH=BTTX(7JJ"?4"2Q`$/RE#H>].$`!)*,0(!BQ!N0JJ$0"N+)`($
MB[%W0/F20#"+I(5BTXT(3:I+?D"2HP$.RG#I>]-C``Q*,0(!BQ!N2ZIC0"^+
M(P(#B[%[0/E^0#"+0X1BTVP(0JK/?T"2@@$-RO#I>]-"`!)*,0(!BQ!N3ZI"
M0"Z+(@("B[%_0/E20#"+8H5BTTL(2ZI.?D"29`$,RM#I>].$`!Y*,0(!BQ!N
M3JJ$0"V+)`($B[&#0/F>0#"+Y(5BTX\(3ZK-?T"2XP$+RK#I>]-C`!)*,0(!
MBQ!N3:IC0"R+(P(#B[&'0/ER0#"+PX5BTVX(3JI,?D"2P@$/RI#I>]-"`!Y*
M,0(!BQ!N3*I"0"N+(@("B[&+0/E>0#"+HH5BTTT(3:K+?T"2I`$.RG#I>].$
M`!)*,0(!BQ!N2ZJ$0"^+)`($B[&/0/F20#"+A(5BTXP(3*I/?D"2@P$-RO#I
M>]-C`!Y*,0(!BQ!N3ZIC0"Z+(P(#B[&30/E^0#"+8X5BTVL(2ZK.?T"28@$,
MRM#I>]-"`!)*,0(!BQ!N3JI"0"V+(@("B[&70/E20#"+XH5BTT\(3ZI-?D"2
MY`$+RK#I>].$`!Y*,0(!BQ!N3:J$0"R+)`($B[&;0/F>0#"+Q(5BTXX(3JK,
M?T"2PP$/RI#I>]-C`!)*,0(!BQ!N3*IC0"N+(P(#B[&?0/ER0#"+HX5BTVT(
M3:I+?D"2H@$.RG#I>]-"`!Y*,0(!BQ!N2ZI"0"^+(@("B[&C0/E>0#"+@H5B
MTTP(3*K/?T"2A`$-RO#I>].$`!)*,0(!BQ!N3ZJ$0"Z+)`($B[&G0/F20#"+
M9(5BTXL(2ZI$?D"28P$,RI#H>]-C`!Y*,0(!BQ!N1*IC0"V+(P(#BZ*K0/EP
M0#"+XX5BTV\(3ZI!``&+X@$+R@U^0))"`!)*H^E[TT)`+(MC;$VJ(0`"BX*$
M8M-."$2J(T`CB\0!#ZIL?$"2$`($BK&O0/G$`0^*@9N7TF'CL?*"Z7O3!`($
M*D)L3*J$0"N+*P(!BV0!!(NQLT#Y@D`BBZ2%8M.-"$VJ2WQ`DK`!#JJR`0Z*
M8P`0BG#I>]-C`!(J$&Y+JC$"`8MC0"^+(P(#B[&W0/ED0#"+@X5BTVP(3*J/
M?$"2D`$-JI(!#8I"`!"*\.E[TT(`$BH0;D^J,0(!BT)`+HLB`@*+L;M`^4-`
M,(MBA6+32PA+JFY\0))P`0RJ<@$,BH0`$(K0Z7O3A``2*A!N3JHQ`@&+A$`M
MBR0"!(NQOT#Y@D`PB^2%8M./"$^J37Q`DO`!"ZKR`0N*8P`0BK#I>]-C`!(J
M$&Y-JC$"`8MC0"R+(P(#B['#0/ED0#"+PX5BTVX(3JJ,?$"2T`$/JM(!#XI"
M`!"*D.E[TT(`$BH0;DRJ,0(!BT)`*XLB`@*+L<=`^4-`,(NBA6+330A-JFM\
M0)*P`0ZJL@$.BH0`$(IPZ7O3A``2*A!N2ZHQ`@&+A$`OBR0"!(NQRT#Y@D`P
MBX2%8M.,"$RJ3WQ`DI`!#:J2`0V*8P`0BO#I>]-C`!(J$&Y/JC$"`8MC0"Z+
M(P(#B['/0/ED0#"+8X5BTVL(2ZJ.?$"2<`$,JG(!#(I"`!"*T.E[TT(`$BH0
M;DZJ,0(!BT)`+8LB`@*+L=-`^4-`,(OBA6+33PA/JFU\0)+P`0NJ\@$+BH0`
M$(JPZ7O3A``2*A!N3:HQ`@&+A$`LBR0"!(NQUT#Y@D`PB\2%8M.."$ZJ3'Q`
MDM`!#ZK2`0^*8P`0BI#I>]-C`!(J$&Y,JC$"`8MC0"N+(P(#B[';0/ED0#"+
MHX5BTVT(3:J+?$"2L`$.JK(!#HI"`!"*<.E[TT(`$BH0;DNJ,0(!BT)`+XLB
M`@*+L=]`^4-`,(N"A6+33`A,JF]\0)*0`0VJD@$-BH0`$(KPZ7O3A``2*A!N
M3ZHQ`@&+A$`NBR0"!(NQXT#Y@D`PBV2%8M.+"$NJ3GQ`DG`!#*IR`0R*8P`0
MBM#I>]-C`!(J$&Y.JC$"`8MC0"V+(P(#B['G0/ED0#"+XX5BTV\(3ZJ-?$"2
M\`$+JO(!"XI"`!"*L.E[TT(`$BH0;DVJ,0(!BT)`+(LB`@*+L>M`^4-`,(O"
MA6+33@A.JFQ\0)+0`0^JT@$/BH0`$(J0Z7O3A``2*A!N3*HQ`@&+A$`KBR0"
M!(NQ[T#Y@D`PBZ2%8M.-"$VJ2WQ`DK`!#JJR`0Z*8P`0BG#I>]-C`!(J$&Y+
MJC$"`8MC0"^+(P(#BW)`,(N#A6+3;`A,JEY^0)*/`0VJD0$-BD(`#XJP\T#Y
MS^M[TT(`$2KO;5ZJ$`(!BT)`+HO#AV+3`@("BU%`+XMBA6+32PA+JC!^0))D
M`0RJ#NI[TU("!(JD]T#YSFU0JJ+[0/F/``&+9`$,BD0"!"I!``&+A$`MBVT(
M7JKD`02+HP$+JH1`+HLQ`@.*CWQ`DJ,!"XKNZ7O3(P(#*LYM3ZIC0"R+(0`#
MB[$#0?DC0"Z+`89BTS`(4*IL?$"2`@(-RJ[_0/G!.IC20@`$2D%,N?*$Z7O3
M0D`KBX1L3*K+`0&+,0(!BV(!`HM$0"2+XH5BTT\(3ZJ2?$"2X@$0RDOJ>]-#
M``-*:VU2JF-`+8LC`@.+L0=!^6M`*XN#A6+3;`A,JGY]0)*"`0_*S>M[TT0`
M!$HQ`@&+K6U>JH1`,(LD`@2+L0M!^8U`+8M$AF+3C@A2JJ1]0)+"`0S*D.A[
MTT(`"THQ`@&+$&Y$JD)`+XLB`@*+L0]!^5)`,(O"AV+32PA>JD]^0))C`0[*
M\.E[TV,`#4HQ`@&+$&Y/JF-`+(LC`@.+L1-!^7Y`,(N#A&+3;0A$JLQ_0)*D
M`0O*D.E[TX0`$DHQ`@&+$&Y,JH1`+HLD`@2+L1=!^9)`,(ODA6+3CPA/JDY^
M0)+B`0W*T.E[TT(`'DHQ`@&+$&Y.JD)`*XLB`@*+L1M!^5Y`,(N"A6+33`A,
MJLM_0)*#`0_*<.E[TV,`$DHQ`@&+$&Y+JF-`+8LC`@.+L1]!^7)`,(O#A6+3
M;@A.JDU^0)+$`0S*L.E[TX0`'DHQ`@&+$&Y-JH1`+XLD`@2+L2-!^9!`,(MD
MA6+3BPA+JAY^0))B`0[*S^M[TT(`$DHQ`@&+[VU>JD)`+(LB`@*+L2=!^5)`
M+XNBA6+330A-JDQ^0)*C`0O*C^E[TV,`$$HQ`@&+[VU,JF-`+HLC`@.+L2M!
M^6]`+XO#AV+3<`A>JN-]0)($`@W*;NA[TX0`$DHQ`@&+SFU#JH1`*XLD`@2+
MLB]!^8Y`+HN$A6+3C`A,JLM]0)*"`1#*<>E[TT(`#TI2`@&+,6Y+JD)`+8M"
M`@*+LC-!^5Y`,8MBA&+33PA#JLU_0)+C`0S*L>E[TV,`#DI2`@&+,6Y-JF-`
M,(M#`@.+;H5BT\X)2ZIC0#&+<GQ`DL0!#\JP-T'Y2^I[TX0`'DIK;5*J$`(!
MBX1`+(L$`@2+L3M!^8M`*XNDA6+3C0A-JFQ]0)*B`0[*D.E[TT(``THQ`@&+
M$&Y,JD)`+XLB`@*+0X9BTU%`,(MC"%*J(GY`DF0`#<JP/T'Y3^A[TXL`"TKO
M;4*J$`(!BVM!+HL+`@N+A(5BTVM!+XN,"$RJ<'U`DH0!`\JO0T'Y#NI[TX0`
M$4K.;5"J[P$!BX1`+8OD`02+CD`NBT2$8M.$"$*JSWU`DH(`"0N)``S*`A``
M^2D!"TJB1T'Y(T$CB^WI>]-"``&+K6U/JD(``XNB`0(+1@`&"P8$`/D&AF+3
MQ@A0JL0`!,K&``@+A``.2@8,`/F#0"R+1.A[TX)L0JJD2T'Y@0`!BR$``XM"
M``$+10`%"P4``/FA3T'Y0@%`^2(``LKAA6+3(0A/JB<`!PL'"`#Y@@``M?U[
MP:C_0PJ1P`-?UBCZ_Y?]>[RI_0,`D?5;`JGW8P.I\U,!J?<#`*KV`P&J@`,`
MM*```/`8-$'Y.`,`M.`"0#D?]`!Q@`,`5&`#`#3U`Q>JH!Y`.!_T`'%```!4
MH/__-;4"%TL3`T#YLP$`M+5^0)/T`QBJX`,3JN(#%:KA`Q>JW_G_EX```#5@
M:G4X'_0`<6`!`%23CD#X\_[_M0``@-+S4T&I]5M"J?=C0ZG]>\2HP`-?UA4`
M@%+K__\7@0(8RZ`&`)$A_$.3P0(`N6`"`(OS4T&I]5M"J?=C0ZG]>\2HP`-?
MUOU[O*G]`P"1\U,!J?43`/FU``#P\P,`JJ"""9$!`$#YH1\`^0$`@-*T``#P
MH=,`D>`#$ZJ^__^7X`$`M*,W0+F"-D'Y0,PCBP$$0/E!V"/XX?[_M``@`)$!
M!$#Y`0``^:'__[6ATP"1X`,3JK#__Y=@_O^UM8()D:$?0/F@`D#Y(```RJ``
M`+7S4T&I]1-`^?U[Q*C``U_6S/G_E_U[N:G]`P"1\U,!J?,#`:K[*P#Y]5L"
MJ?=C`ZGY:P2I]`,`JK4``/!@`D`YH8()D2(`0/FB-P#Y`@"`TA_T`'%S%I.:
MX`,3JD'Y_Y?W`P"JH9,!D>`#%*J.__^7]@,`JJ`'`+0Z^?^7'T`WZX(&`%2V
M9T"YN```\(`"0#D?]`!Q(`L`5``+`#3@`Q2J`@``%($``#0!'$`X/_0`<:'_
M_U0``!1+&3=!^?<*`!'@`@`+8_G_ER!;-O@`"@"THV=`N8`&`)$"-T'Y@0)`
M.4)88_A!```YH0``-08``!0!%$`X01P`.&$``#0_]`!Q@?__5*`'@%)!!`"1
M0```.6`60#@@%``XP/__-0``@%*U@@F1HC=`^:$"0/E!``'*(0<`M?-30:GU
M6T*I]V-#J?EK1*G[*T#Y_7O'J,`#7]8``(#286I@.,%J(#@`!`"1H?__->[_
M_Q>X``#P&S=!^6`#0/E@!`"TX`,;JA8`@%(!C$#XU@8`$<'__[7`"@`1`'Q]
MDZ$``/`BB$*Y@@$`-.$#`*K@`QNJ7OG_EP`W`?G@`@"TVGY`D_D#`*I:!P"1
M/WLZ^+9G`+FQ__\7(@"`4B*(`KD?^?^7^0,`JH`!`+3:?D"3X0,;JD+S?=/5
M^/^7&3<!^?+__Q<``(!2K___%P`"@-(6`(!2X___%P``@!+$__\72_G_E_U[
MLZG]`P"1\U,!J?5;`JGW8P.IM```\/4#`*J!@@F1(@!`^:)G`/D"`(#28```
MM`$`0#EA`0`UE(()D:%G0/F``D#Y(```RH`(`+7S4T&I]5M"J?=C0ZG]>\VH
MP`-?UM+X_Y?V`P"J@/[_M!@``-`8XQ^1X`,6JGCY_Y?E`P"JX`0`M*!,0#D?
MN`!Q(`4`5.`#%:JS3`"1K/C_E_<#`*K@`Q.JJ?C_EP``%PL`"``1`'Q`D^'X
M_Y?W`P"JY0,3JN0#%:KC`QBJ`@"`DB$`@%*B^/^7HB,!D>$#%ZH``(!2IOC_
MEQ\$`#&@``!4H%M`N0`,%!(?$$!QH`(`5.`#%ZJ2^?^7X`,7JDSY_Y?@`Q:J
M4OG_E^4#`*I@^_^UX`,6JO[X_Y?@`Q6J,/G_E\/__Q>@4$`Y`/K_-!^X`'&A
M^O]4H%1`.8#Y_S32__\7X`,7JJS__Y?L__\7]/C_E_U[O:G]`P"1\U,!J;,`
M`/#U$P#Y8%)"N>'X_Y<!<$#Y8%)"N34$0/G=^/^7%+1".6!20KF4&@`2V?C_
MEP`$0/D`0$!Y`"`94X`"`"J@!@!Y8%)"N=+X_Y<!<$#Y8%)"N30$0/G.^/^7
M`0``T`(`@-(AX"V1^OC_EX`6`/E@4D*YQ_C_EP%P0/E@4D*Y-`1`^</X_Y<!
M1$/Y8%)"N8$:`/F_^/^7`7!`^6!20KDT!$#YN_C_EP#`0/F``P"T8%)"N;?X
M_Y<`P$#Y`51`^6!20KF!'@#YLOC_EP%P0/E@4D*Y(01`^3\@`/FM^/^7`7!`
M^6!20KDA!$#Y/Q``^:CX_Y<!<$#Y8%)"N3,$0/FD^/^7`(Q!^6`F`/GS4T&I
M]1-`^?U[PZC``U_6`0"`TNC__Q?]>[ZI_0,`D?-3`:FS``#P]`,`JF!20KF5
M^/^7`F`&D>$#%*H``(!2V?C_EZ```#0``(!2\U-!J?U[PJC``U_68%)"N8KX
M_Y<`J$&Y``P4$A\00''@``!48%)"N83X_Y<`J$&Y``P4$A\H0'$A_O]400"`
M4N`#%*J=^/^7'P`?:^`7GQKS4T&I_7O"J,`#7];_!T#1`P``T/^#`-'B_X'2
M_7N]J?T#`)'U6P*I\U,!J;,``/#U`P"J8``@D6.""9'V`P&J9`!`^:0G"/D$
M`(#2H2,!D0KX_Y<?`!]K#00`5`$$`%&B(P&1-'Q`DT)H=#A"`P`T%'Q`DZ`C
M`9'B`Q2JX06`4J`?`/G1^/^7@`(`M*```/``4$*Y5?C_EZ(?0/GC`Q2JX0,5
MJM'X_Y=S@@F1H2=(^6`"0/D@``#*X`$`M?-30:GU6T*I_7O#J/\'0)'_@P"1
MP`-?U@']_S6@``#P`%!"N4+X_Y?B`Q:JX0,5JAOX_Y?N__\72?C_EZ```/#]
M>[^I_0,`D0!00KDX^/^7`P``T.+__]`!``#08Z`<D?U[P:A"P#R1(4`@D73X
M_Q?]>[ZI_0,`D?,+`/FS``#P8%)"N2KX_Y?M__^78%)"N2?X_Y?S"T#Y!```
MT`(``-"$X"V1`0``T/U[PJ@%`(!2XP,$JD(0!Y$AP""1@/C_%_\+0-'_PP#1
M_7N]J?T#`)'U$P#YM0``T/-3`:F@@@F1`0!`^:$O$/D!`(#2W/?_E^0#`"JA
M(P&1H1\`^04``+`#``"PH!]`^:4@(9%C0"&1(@""TB$`@%*=]_^70`3X-Z%#
M`)$`"H+2```!BP(`@M(`0`#1H!L`^:`?0/FA&T#YG_?_E_,#`*KS`O@W8`8`
M$0!\0)/&]_^7]`,`JD`"`+1S?D"3H1M`^>(#$ZIX]_^7GVHS..`#%*JU@@F1
MHB]0^:$"0/E!``'*(0$`M?-30:GU$T#Y_7O#J/\+0)'_PP"1P`-?U@``@-+T
M__\7[/?_E\3__Q?_!T#1`@``L/]#`-']>[JI_0,`D?-3`:GU6P*I]V,#J?EK
M!*G[*P#YM@``T/,#`*I`H"&1PH()D?0#`:I#`$#YHS<(^0,`@-*ADP&1L/W_
ME_4#`*KA!8!2X`,3JB_X_Y>``@"T````L.$#$ZH`X"&1`_[_E^`#$ZK6@@F1
MHC=(^<$"0/E!``'*00L`M?-30:GU6T*I]V-#J?EK1*G[*T#Y_7O&J/\'0)'_
M0P"1P`-?UN`#$ZH8``"P1/?_E_H#`"H!(R*1X`,4JCSW_Y?[`P"JH/S_M!<`
M`+`9``"P]X(AD3E#(I&THP&18`-`.1\`'VM[$Y>:M0``M.$#&ZK@`Q6JTO?_
MET`%`#3@`QNJ+_?_E^$#`"I@PR"+`/!?.!^\`'$!`0!4(00`42!\0)-B`P"+
M?VL@.$#P7S@?O`!Q0/__5$`'`!$!``$+/_P_<<SX_U0#``"P`@""TB$`@%+D
M`QNJY@,3JN4#&:IC8"*1X`,4JKL``-`9]_^78%-"N7_W_Y<"8`:1X0,4J@``
M@%(;]_^7X```-6!30KEX]_^7`*A!N0`,%!(?($!QX```5`$C(I$``(#2`??_
ME_L#`*I@^?^UJ?__%R$`@%+@`Q2JB_?_E^#^_S4```"PX0,4J@#@(9&G_?^7
MX`,4JB#W_Y>C__\7;O?_EP$`0#G!```T`@0`D3^\`'$`$(*:011`.*'__S7`
M`U_6_7N^J?T#`)'S4P&I\P,`JF`#`+04`$`Y-`,`-.;V_Y<`!`#18@(`BW\"
M`NMB`0!48&I@.!^\`'&@``!4'@``%$``0#D?O`!Q80,`5$($`-%?`!/K8?__
M5'\"`NOA`P!4G[X`<<```%3S4T&I````L/U[PJ@`0"*1]_;_%T``@-()]_^7
MX0,`JN`$`+0"``"P0H`AD4(`0'DB``!Y\U-!J?U[PJC``U_60`!`.1^\`'%`
M`0!40@0`T7\"`NMC__]4?P("ZZ$``%3F__\70`!`.1^\`'&!``!40@0`T7\"
M`NMC__]40@`3RT`(`)$?!$#QJ`$`5*```-#A`Q.J`"`*D0,`@M(4(`"10@0`
MD>`#%*KI]O^7X`,4JO-30:G]>\*HP`-?U@``@-+S4T&I_7O"J,`#7];]>[BI
M`0``L````+`AH!R1_0,`D0"`(I'S4P&I]5L"J?<;`/FS``#0)AQ!J2040JEB
M@@F1(6!`>4,`0/FC/P#Y`P"`TJ'C`'FF'P6II!<&J1+]_Y<5``"P````L!8`
M`+``P"*1%P``L!0``+`+_?^7E`(DD0```+``X"*1!_W_EP```+``(".1!/W_
MEZ!"(Y$"_?^7````L`"`(Y'__/^7P*(AD?W\_Y?@PB.1^_S_E^`#%*KY_/^7
M````L`!`))'V_/^7````L`#@(9'S_/^7````L`"`))'P_/^7````L`#`))'M
M_/^7````L*$S`9$``"61M/S_EX```+3A`P"JX`,4J@S]_Y<```"PH3,!D0!@
M)9&L_/^7H```M`(``+#A`P"J0,`ED0/]_Y<```"PH3,!D0``)I&C_/^70`(`
MM.$#`*K`HB&1^_S_EP$``+"@0B.1(>`FD7.""9'V_/^7H3]`^6`"0/D@``#*
M(`,`M?-30:GU6T*I]QM`^?U[R*C``U_6````L*$S`9$`0":1C?S_EZ```+3A
M`P"JX,(CD>7\_Y?J__\7`0``L$(!@-(AH":1H(<!D7[V_Y>`_/\UH:\!D>#"
M(Y';_/^7X/__%Z3V_Y?]>[VI_0,`D?-3`:FT``#0LP``T&"""9$!`$#YH1<`
M^0$`@-*`.D*Y'P0`,2`!`%1S@@F1HA=`^6$"0/E!``'*@0(`M?-30:G]>\.H
MP`-?U@```+"ADP"1`,`CD67\_Y<@`0"T`0!`.3\`'VOB!Y\:/\``<>`'GQI`
M```*@#H"N>S__Q<``(!2@#H"N>G__Q=_]O^7_7N_J?T#`)$8]O^7I_;_EX``
M`+0``$#Y_7O!J,`#7]8``(#2_?__%_U[MJD!``"P_0,`D2&@')$AX`"1\U,!
MJ?5;`JGW8P.I^6L$J;<``-#V`P"JXH()D3,`0/E#`$#YHT\`^0,`@-(F!$#Y
M)!1!J2(,0JD@&$#YLS,`^:8W`/F@2P#YI!<'J:(/"*D3`P"T`0``L````+"U
MHP&1.2`BD1A@(I$&```4X0,6JL_V_Y=``P"TLX9`^+,!`+2A<P&1X`,3JB;\
M_Y?T`P"J8```M`$`0#FA_O\UX`,3JN$#%JI[_/^7LX9`^+/^_[7W@@F1H4]`
M^>`"0/D@``#*8`,`M?-30:GU6T*I]V-#J?EK1*G]>\JHP`-?UN`#%JJ_]?^7
M^@,`JN`#%*J\]?^70`,`BP`(`)'U]?^7^@,`JN8#%*KE`QFJY`,6JN,#&*H"
M`("2(0"`4K7U_Y?A`QJJX`,3JEO\_Y?4__\7)/;_E_\C0-$!``"P_T,%T2&@
M')$DX`*1(B`"D?U[NJG]`P"1HV,"D?5;`JGU`P"J($!`^?-3`:GW8P.I^6L$
MJ?MS!:F@2P#YN```T"!D0/D:``"P)AQ'J6`(`/G_0P#1@`1`J6`$`*E()$"I
MI$,`D0,SD-*H)PNIIA\(J4@D0JE&'$&I8P`$BP*#"9&A\P&10*,AD40`0/ED
M``#Y!`"`TJ8?#*FH)PVIT_O_E_,#`*I@``"T`0!`.0$@`#5W__^7]`,`JB`@
M`+3@`Q2J>?7_EP#X?],`!`"1LO7_EQ<``+"$`D`Y]@,`JO,#`*KW(B>1)`$`
M-.`#$ZKC`Q>J`@"`DB$`@%)S"@"1;O7_EX0>0#@D__\UH%M`^:'#!I&TPP*1
M-]`$T8```+4/```4@(Y`^*`!`+3A`Q>JK_O_E_,#`*I@__^T`0!`.2'__S0J
M_?^7X/[_-.`#$ZI^]?^7\P,`J@`#`+6S0T#YDPH`M&`"0#DT`(!2@`$`-5``
M`!0`-)#2H4,`D0```8L`S#2+`"1`T1-H1_DS"0"T8`)`.90&`!'`"``TX`,3
MJA/]_Y>`_O\TX`,3JF?U_Y?S`P"J`/[_M.`#$ZH9``"P.O7_E_0#`*K@`Q:J
M-_7_EP``%`L7$!`1]WY`D^`#%ZIN]?^7]`,`J@8``+`#``"PYP,6JL9`)Y'D
M`Q.J8V`GD25#(I$"`("2(0"`4BOU_Y<!.(!2X`,4JBCV_Y<?!``QP`0`5+,`
M`-!@4D*YB_7_EP)@!I'A`Q2J``"`4L_U_Y>`!0`TH```T`(``+"C`D#YY`,4
MJD+`*9$A`(!2`"1!^:KU_Y<``(#2HD,`D0$SD-(8@PF1(0`"BR(`0/D!`T#Y
M00`!RJ$Y`+6_`P"1\U-!J?5;0JGW8T.I^6M$J?MS1:G]>\:H_R-`D?]#!9'`
M`U_6$P"`TL'__Q?X]?^7!0!`N;]$`'$`^_]4H```T`(``+"C`D#YY`,4JD*@
M)Y$A`(!2`"1!^8GU_Y<``(#2W___%V!20KE9]?^7`*A!N0`,%!(?$$!Q`?K_
M5&!20KE3]?^7%K!!N?GT_Y??`@!K0?G_5&!20KE-]?^7`*A!N0`@`!(?``=Q
M@?C_5.`#%ZH7]?^7\P,`J@```+"A\P&1`.`OD2?[_Y?@,@"TM@)`^?OT_Y?A
M`P"JX`,6JE[]_Y?V`P"J`#(`M.`#%JK,]/^7'PP`<?<#`*KM`0!4`'Q`DP$`
M`+``$`#1(:`HD<`"`(MC]?^7``$`-?\2`'%`*`!4X!(`4<#"((L`\%\X'[P`
M<:`G`%2/_O^7P```-0$`@%+@`Q:JGO7_E_L#`"H`"@`U`0``L````+`AX":1
M`,`CD3E#(I$6``"P6OO_EQ4`@%+C]/^7Y@,`*@<``+`#``"PY^`MD>4#&:IC
M("F1Y`,4J@(`@)(A`(!2X`,3JO<#!ZK68BF1HO3_EQ$``!28]?^7``!`N1]$
M`'%!`@!4T/3_E[4&`!'F`P`J]P,`^><#%2KE`QFJY`,4JN,#%JH"`("2(0"`
M4N`#$ZJ1]/^7`3B`4N`#$ZJ.]?^7'P0`,8#]_U3@`Q2J0O7_E^$#$ZI`HR&1
M,/O_E^`#$ZJ%_O^7X`,3JF___Q>"_O^7X`,3JJ3T_Y=K__\7H,,&D1,`@-*V
M8P*1%]`$T6!J=OB@`0"TX0,7JL3Z_Y=@``"T`0!`.6$``#5S(@"1^/__%Y7T
M_Y?T`P"J(-[_M7,B`)'S__\7%```L*`!@-*4`B>1[_[_%T(`@%(A`H"2PO3_
ME\(`@-*AHP:1X`,;*C[U_Y>@HT8Y@```-:"G1CD?#`%Q8!\`5`$`@-("`(!2
MX`,;*K>#`Y&T]/^7OX<`^2!QE=(A8(32H/F]\J!W`/G`CHK2H>BL\D`&HO*@
M?P#Y`#Z<TJ%S`/E`>KCRP9^;TD$7L_*@@P#YH7L`^>#B`)&_BP#YOUL!N:`S
M`/D"`)#2H:,&D>`#&RH<]?^7'P`?:_P#`*KU`P`J[0@`5**'0/F`?T"300P`
MBR%\0))?``'KHHM`^4D``%1"!`"10'1`BZ"+`/F@6T&YH8<`^6`5`#05"(!2
MH:,&D;4"`$O@PB"+GP,5:P#@`)&5TY4:MGY`D^(#%JH5]/^7H%M!N:`"``N@
M6P&Y'P`!<:'[_U2@HP:1E0,52QP`%HO@`Q>J!_;_E[_^`'&M%`!4M0(!4;9^
M!E.V;P"YU@8`D98;%HNB8P21X`,7JHHO0*F()T&IAA]"J8070ZE*+`"I2"0!
MJ48<`JE$%`.IG`,!D?3U_Y>?`Q;K8?[_5*!O0+FU&@!+H#-`^:)^0)/A`Q:J
M`PF`TB_T_Y>U6P&Y`@"0TJ&C!I'@`QLJUO3_EQ\`'VO\`P"J]0,`*FSW_U3@
M`QLJ;/3_E[6'0/FB0SG1XP^`$J$B0].VBT#Y(`0`$4+`(8L?X`!Q0Z`].0P/
M`%2BPP:10,`@B^(&@%)"``%+`&`"T0$`@%)"?$"3,O3_E\#^4-/!_EC3H$<%
M.:#^6-.A0P4YH?Y0TZ!3!3F@@P.1MD\%.=;^2-.U7P4YM?Y(T[9+!3D7``"P
MH5<%.;;C!9&U6P4YO/7_EZ5S0/G<H@"1HW=`^?4B)Y&D?%C3IOQ0TZ6/!3FE
M_$C3HGM`^:6+!3EE_%C3HY\%.:63!3EE_%#38_Q(TZ%_0/FCFP4Y0_Q8TZ*O
M!3FCHP4Y0_Q0TT+\2-.@@T#YHJL%.2+\6-.BLP4Y(OQ0TZ*W!3D"_%C3H;\%
M.2'\2-.BPP4YHL,&D:#/!3E;/`'1H;L%.0'\4-.D@P4Y`/Q(TZ:'!3FEEP4Y
MHZ<%.:''!3F@RP4Y`@``%&070#C@`Q:JXP,5J@(`@)(A`(!2U@H`D9SS_Y??
M`ASK`?__5`<``)`#``"0Y^`MD:;C!9$E0R*1Y`,4JF/@*)$"`("2(0"`4N`#
M$ZJ_@P8YCO/_E^`#%*I$]/^7X0,3JD"C(9$R^O^7X`,3JH?]_Y?@`Q.J<?[_
M%[RC!I%I__\7M09`^778_[3@`Q6J>_/_EQ\,`/'IU_]4`!``T0$``)`AP"B1
MH`(`BQ3T_Y<?`!]KUA*5FK?^_Q?V`QRJ</__%^('@%)"``%+H8,#D2#`((L!
M`(!20GQ`DP#@`)&[\_^7H(,#D57U_Y>_IP#YH&,$D1]\`*D??`&I'WP"J8+_
M_Q>@JT8Y'P0!<8'@_U2@KT8Y'PP!<2'@_U2@LT8Y'R`!<<'?_U2@MT8Y'Q0!
M<6'?_U1"`(!2(0>`DN`#&RJO\_^7H:,&D2(%@-+@`QLJ*_3_EP<``)`#``"0
MY^`MD::C!I$E0R*1Y`,4JF/@*)$"`("2(0"`4N`#$ZI$\_^7N/[_%[8"0/EP
M_O\7M//_E_U[N:G]`P"1^6L$J;D``+"Z``"P\U,!J?5;`JGW8P.I^W,%J4"#
M"9$!`$#YH3<`^0$`@-(@4T*YF?/_EP(``)`C`(!2H9,!D0.D`CE`0".1>/G_
MEX```+0!`$`Y/\0`<4`1`%2"_/^7(%-"N;4``-"+\_^7`0``D&,!@%(B`(!2
M(2`KD9KS_Y?`!@"T`0A`^:`B#I$`@%"X-Q1`^1\$`'$-!@!4&("`4A0`@%(S
M`(!2-D,)D1@$H'(+```400A`^>`#'*JJ\_^7(`0`-:`B#I%S!@`1E`8`$0"`
M4+@?`!-KK0,`5,`"0+EM\_^7`P"`4H)^0)/A`Q>JU?/_E_L#`*I@`@"T`@!`
M^:$B#I%`#$"Y(0!1^```&`H?`!!Q/-AS^.#\_U3``D"Y7?/_EV$#0/E#`(!2
M`@"`TD7S_Y?A`P"JX`,<JHKS_Y<@_/\TH"(.D0"`4+@!!`!1/P`4:\`)`%0@
M4T*YM```L$WS_Y<!``"08P"`4B(`@%(A0"N17//_E_,#`*J``0"T@%)"N43S
M_Y=A"D#Y`@``D$)@*Y$A`$#Y&_/_EV`*0/D``$#Y``Q`N2`0L#<@4T*YM@``
ML#CS_Y<!``"08P"`4B(`@%(A@"N11_/_E_,#`*J@`0"T````D*&3`9$`X"&1
M$OG_E_0#`*K`4D*Y]`H`M"GS_Y=A"D#YX@,4JB$`0/D!\_^7(%-"N;8B#I&W
M``"P(?/_EQ^D`CD"``"0H9,!D4"@(9$!^?^7P((1^/0#`*J@!`"T`3B`4J_S
M_Y<!!``1/P0`<6D``%0?1`!Q00P`5%J#"9&A-T#Y0`-`^2```,J`"P"U\U-!
MJ?5;0JGW8T.I^6M$J?MS1:G]>\>HP`-?U@`$0#G@[O\T=?__%Q\$`'%-]O]4
M,P"`4C1#"9&``D"Y<P8`$?SR_Y?A`Q>JJO+_EZ`B#I$`@%"X'P`3:PS__U2F
M__\7P`)1^-S\_Y?`@A'XH`<`M&$*0/D`@(!2``2@<B$`0/DB#$"Y0```"A\`
M$''A!`!4(`A`^;4B#I&T`E'XX0,4J@SS_Y?U`P`J80I`^0"`@%(`!*!RE`)`
M^2$`0/DB#$"Y0```"A\`$''A`0!4(@A`^0```)#C`Q4JX0,4J@!`+)$4\_^7
MT_+_EZ`B#I%B"D#Y`0!1^$``0/DA`$#Y5OK_EZC__Q<@4T*YRO+_EV$*0/D"
M`(#20P"`4B$`0/FQ\O^7X@,`JNO__Q?@4D*YP?+_EV$*0/E#`(!2`@"`TB$`
M0/FH\O^7U/__%X!20KFY\O^780I`^2$`0/D2\_^7>___%P```)``H"N1\O+_
ME[WR_Y?!`E'X!```D.,#`"KB`Q2J@.`LD2$`0/GJ\O^7_7N^J?T#`)'S4P&I
M]`,`JDS[_Y?S`P"J``!`.<```#1A!@"1'[P`<7,2@9H@%$`XH/__-07\_Y=`
M`0`T-`$`M(`"0#G@```T`0``D.`#$ZHA0">1'//_EW\"`.N```!4\U-!J?U[
MPJC``U_6X`,4JO-30:G]>\*H3?G_%_U[OJG]`P"1\PL`^;,``+!@4D*YA?+_
MEP$`@!)[\O^78%)"N8'R_Y?S"T#YX?__T`(`@-+]>\*H(1`SD0?S_Q>C``"P
M9,`(D60``+1C&$'Y+O+_%P,`@-(L\O\7_7N\J?T#`)'S4P&I]5L"J;0``)"U
M``"0M0(WD90B-Y&4`A7+]@,"JI3^0Y,3`(#2]V,#J?@#`"KW`P&JWO'_ES0!
M`+2C>G/XX@,6JN$#%ZK@`Q@J<P8`D6``/]9_`A3K(?__5/-30:GU6T*I]V-#
MJ?U[Q*C``U_6P`-?UOU[OZG]`P"1_7O!J,`#7]8!``(``````'!E<FQX<VDN
M8P````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````
M````V%M```````#H6T```````/!;0```````^%M`````````7$```````!A<
M0`````````````````#06T```````&!80`````````````````!P64``````
M`+!;0```````N%M```````#`6T```````,A;0`````````````````"86T``
M`````*!;0``````````````````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$
M>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2
M.CI"3T]4`````&5X90``````+W!R;V,O)6DO)7,``````"X`````````4$%2
M7U1%35```````````%!!4E]04D]'3D%-10`````Z`````````"\`````````
M)7,E<R5S``!015),-4Q)0@``````````4$523$Q)0@!015),-4]05```````
M````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140``````%!!
M4E]#3$5!3@````````!005)?1$5"54<`````````4$%27T-!0TA%````````
M`%!!4E]!4D=#``````````!005)?05)'5E\P````````4$%27T=,3T)!3%]$
M14)51P``````````4$%27T=,3T)!3%]435!$25(`````````4$%27U1-4$1)
M4@```````%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.````````
M``!005)?0TQ%04X]````````,0````````!365-414T``"4P,G@`````<&%R
M+0`````E<R5S)7,E<P``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````'!A<FP`
M````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S
M)7-T96UP+25U+25U)7,``````````"5S.B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO
M=7(@;W!E<F%T:6]N*0H```````!!4D=6`````!@`````````<&5R;``````P
M`````````%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y````````
M```E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@``````````)7,````````M90```````"TM````
M````55-%4@````!54T523D%-10``````````5$U01$E2``!414U01$E2`%1%
M35``````5$U0```````O=&UP`````$Q$7TQ)0E)!4EE?4$%42`!,24)0051(
M`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!4EE?4$%42`````````!32$Q)
M0E]0051(````````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D
M>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L
M($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I
M<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P
M87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@
M)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O
M"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[
M('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*
M<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M
M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D
M978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U
M=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@
M)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%2
M1U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?
M05)'0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF
M;W(@*&ME>7,@)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'
M5E\O.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O
M;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A
M=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E
M;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*
M;7D@)&)U9CL*<V5E:R!?1D@L("TX+"`R.PIR96%D(%]&2"P@)&)U9BP@.#L*
M;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["G-E96L@7T9(+"`M
M,3(L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+3$R("T@=6YP
M86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@
M*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B
M=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*
M;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I
M(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]
M?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE
M9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*
M;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD[
M"FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*
M8VQO<V4@)&]U=#L*8VAM;V0@,#<U-2P@)&9I;&5N86UE.PI]"B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%
M35!]+R1B87-E;F%M921E>'0B.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB
M*3L*;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I
M;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*?0IE
M;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@
M/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B
M=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U
M;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*
M;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@
M?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I
M('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S
M=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K
M97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F
M:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F
M:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@
M)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H
M.PI]"F5L<V4@>PIM>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG
M+"`D9FEL96YA;64M/GMC<F-]*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T
M*3L*<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PIC;&]S92`D;W5T.PI]
M"F]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D
M9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@
M)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O
M<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R
M(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@
M97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@
M9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO
M="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]
M"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD
M;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*
M8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A
M=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@
M<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO
M861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L
M>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@
M979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?
M14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B
M("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K
M*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG
M=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U
M;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@<V]R="!["FQE;F=T:"@D8BD@/#T^
M(&QE;F=T:"@D82D*?2!G<F5P('L*(2]"4T1004XO"GT@9W)E<"!["B@D8G5N
M9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]
M*3L*?2!`24Y#.PIM>2`E9FEL97,["B]>7SPH+BLI)"\@86YD("UE("0Q(&%N
M9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PHD9FEL97-[)%]]*RL@9F]R
M('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML
M:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL
M97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN
M8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@
M>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ
M6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S
M=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*
M:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H
M+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N
M9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B
M+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE
M*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&
M24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B
M.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,
M13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T
M<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD
M9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC
M;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT
M96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II
M<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII
M9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;
M.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI
M('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F
M:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@
M.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M
M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N
M<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE
M("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,
M:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@
M)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[
M4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@
M)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T
M<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y
M(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%
M>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD
M;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D
M*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*
M<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I
M;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q
M=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N
M;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U
M8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA
M3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U
M:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P[
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N
M9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D
M('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C
M86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ
M0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U
M<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ
M<V-A;&%R('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2![
M"B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H
M"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2
M(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@
M=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T
M:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@
M9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97
M:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I
M;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]
M("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@
M?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<
M5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R
M+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G
M;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE
M;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D
M8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P
M<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@
M*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*
M;7D@*"1E>'0L("1C<F,I(#T@0%\["FUY("@D9F@L("1F:6QE;F%M92D["B1F
M:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PII9B`H)$5.5GM005)?
M0TQ%04Y]*2!["G5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PIP
M=7-H($!T;7!F:6QE+"`D9FEL96YA;64["GT*96QS92!["G)E='5R;B`H=6YD
M968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["GT*;W!E;B`D9F@L
M("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR971U
M<FXH)&9H+"`D9FEL96YA;64I.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@
M*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'
M3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M
M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N
M86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S
M='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@
M;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]
M"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE
M("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I
M<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI
M('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@
M)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%
M)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\
M(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG
M971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ
M1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@
M<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6
M>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B
M0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#@F0```````""9```````````````````$`
M`````````0`````````!``````````4"`````````0````````!4`@``````
M``$`````````IP,````````,`````````$@>0```````#0`````````05T``
M`````!D`````````P)U!```````;``````````@`````````&@````````#(
MG4$``````!P`````````"`````````#U_O]O`````&`"0```````!0``````
M``"@$$````````8`````````(`9````````*`````````$(%````````"P``
M```````8`````````!4````````````````````#`````````.B?00``````
M`@````````!X!@```````!0`````````!P`````````7`````````-`70```
M````!P`````````H%T````````@`````````J``````````)`````````!@`
M````````_O__;P````#(%D```````/___V\``````P````````#P__]O````
M`.(50```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````V)U!````````````````````````````````````
M`````````````&`>0```````8!Y```````!@'D```````&`>0```````8!Y`
M``````!@'D```````&`>0```````8!Y```````!@'D```````&`>0```````
M8!Y```````!@'D```````&`>0```````8!Y```````!@'D```````&`>0```
M````8!Y```````!@'D```````&`>0```````8!Y```````!@'D```````&`>
M0```````8!Y```````!@'D```````&`>0```````8!Y```````!@'D``````
M`&`>0```````8!Y```````!@'D```````&`>0```````8!Y```````!@'D``
M`````&`>0```````8!Y```````!@'D```````&`>0```````8!Y```````!@
M'D```````&`>0```````8!Y```````!@'D```````&`>0```````8!Y`````
M``!@'D```````&`>0```````8!Y```````!@'D```````&`>0```````8!Y`
M``````!@'D```````&`>0```````8!Y```````!@'D```````&`>0```````
M8!Y```````!@'D```````&`>0```````8!Y```````!@'D```````&`>0```
M````8!Y```````!@'D```````&`>0```````8!Y```````!@'D```````&`>
M0```````8!Y```````!@'D````````````````````````````#_____````
M`"A<0```````1T-#.B`H56)U;G1U+TQI;F%R;R`T+CDN,BTR,'5B=6YT=3$I
M(#0N.2XR`$=#0SH@*%5B=6YT=2],:6YA<F\@-"XY+C(M,3!U8G5N='4Q,2D@
M-"XY+C(``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N
M9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV
M97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN
M:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+FEN:71?87)R87D`
M+F9I;FE?87)R87D`+FIC<@`N9'EN86UI8P`N9V]T`"YG;W0N<&QT`"YD871A
M`"YB<W,`+F-O;6UE;G0`````````````````````````````````````````
M```````````````````````````````````````````````````````+````
M`0````(```````````)``````````@```````!L````````````````````!
M````````````````````$P````<````"`````````!P"0```````'`(`````
M```@````````````````````!````````````````````"$````'`````@``
M```````\`D```````#P"````````)`````````````````````0`````````
M```````````T````]O__;P(`````````8`)```````!@`@```````,`#````
M````!0`````````(````````````````````/@````L````"`````````"`&
M0```````(`8```````"`"@````````8````!````"``````````8````````
M`$8````#`````@````````"@$$```````*`0````````0@4`````````````
M``````$```````````````````!.````____;P(`````````XA5```````#B
M%0```````.``````````!0`````````"``````````(`````````6P```/[_
M_V\"`````````,@60```````R!8```````!@``````````8````#````"```
M`````````````````&H````$`````@`````````H%T```````"@7````````
MJ``````````%``````````@`````````&`````````!T````!````$(`````
M````T!=```````#0%P```````'@&````````!0````P````(`````````!@`
M````````?@````$````&`````````$@>0```````2!X````````4````````
M````````````!````````````````````'D````!````!@````````!@'D``
M`````&`>````````<`0``````````````````!``````````$`````````"$
M`````0````8`````````T")```````#0(@```````$`T````````````````
M```(````````````````````B@````$````&`````````!!70```````$%<`
M```````0````````````````````!````````````````````)`````!````
M`@`````````@5T```````"!7````````$$$```````````````````@`````
M``````````````"8`````0````(`````````,)A````````PF`````````0`
M```````````````````$````````````````````H@````X````#````````
M`,"=00``````P)T````````(````````````````````"```````````````
M`````*X````/`````P````````#(G4$``````,B=````````"```````````
M``````````@```````````````````"Z`````0````,`````````T)U!````
M``#0G0````````@````````````````````(````````````````````OP``
M``8````#`````````-B=00``````V)T``````````@````````8`````````
M"``````````0`````````,@````!`````P````````#8GT$``````-B?````
M````$`````````````````````@`````````"`````````#-`````0````,`
M````````Z)]!``````#HGP```````$`"```````````````````(````````
M``@`````````U@````$````#`````````"BB00``````**(````````@````
M````````````````"````````````````````-P````(`````P````````!(
MHD$``````$BB````````:!````````````````````@`````````````````
M``#A`````0```#````````````````````!(H@```````%<`````````````
M```````!``````````$``````````0````,`````````````````````````
HGZ(```````#J`````````````````````0``````````````````````
